custom_animated_switcher library
A library providing a widget that can be used to animate transitions between two different widgets.
Classes
- CircularRevealClipper
- A custom clipper that creates a circular reveal effect. This clipper is used to clip the child widget during the animation.
- CustomAnimatedSwitcher
- A versatile widget that animates transitions between two widgets.
- CustomAnimatedSwitcherState
- The state class for the CustomAnimatedSwitcher widget.
- RectangularRevealClipper
- Example of a rectangular clipper. This can be used in place of the circular clipper
Enums
- AnimationType
- An enum to define the types of transition animations.